searchData={"items":[{"type":"module","title":"LiveExWebRTC.Publisher","doc":"`Phoenix.LiveComponent` for sending audio and video via WebRTC from a browser to a Phoenix app (browser publishes).\n\nIt will render a view with:\n* audio and video device selects\n* audio and video stream configs\n* stream preview\n* transmission stats\n\nOnce rendered, your `Phoenix.LiveView` will receive `t:init_msg/0` and will start getting\nRTP audio and video packets that can be forwarded to other clients.\n\nPublisher always negotiates a single audio and video track.","ref":"LiveExWebRTC.Publisher.html"},{"type":"module","title":"Assigns - LiveExWebRTC.Publisher","doc":"* `ice_servers` - a list of `t:ExWebRTC.PeerConnection.Configuration.ice_server/0`,\n* `ice_ip_filter` - `t:ExICE.ICEAgent.ip_filter/0`,\n* `ice_port_range` - `t:Enumerable.t(non_neg_integer())/1`,\n* `audio_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `video_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `gen_server_name` - `t:GenServer.name/0`","ref":"LiveExWebRTC.Publisher.html#module-assigns"},{"type":"module","title":"JavaScript Hook - LiveExWebRTC.Publisher","doc":"Publisher live component requires JavaScript hook to be registered under `Publisher` name.\nThe hook can be created using `createPublisherHook` function.\nFor example:\n\n```javascript\nimport { createPublisherHook } from \"live_ex_webrtc\";\nlet Hooks = {};\nconst iceServers = [{ urls: \"stun:stun.l.google.com:19302\" }];\nHooks.Publisher = createPublisherHook(iceServers);\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  // ...\n  hooks: Hooks\n});\n```","ref":"LiveExWebRTC.Publisher.html#module-javascript-hook"},{"type":"module","title":"Examples - LiveExWebRTC.Publisher","doc":"```elixir\n<.live_component\n  module={LiveExWebRTC.Publisher}\n  id=\"publisher\"\n  ice_servers={[%{urls: \"stun:stun.l.google.com:19302\"}]}\n/>\n```","ref":"LiveExWebRTC.Publisher.html#module-examples"},{"type":"type","title":"LiveExWebRTC.Publisher.init_msg/0","doc":"Message sent to the `Phoenix.LiveView` after component's initialization.\n\n* `pc` - `ExWebRTC.PeerConnection`'s pid spawned by this live component\n* `audio_track_id` - id of audio track\n* `video_track_id` - id of video track","ref":"LiveExWebRTC.Publisher.html#t:init_msg/0"},{"type":"module","title":"LiveExWebRTC.Subscriber","doc":"`Phoenix.LiveComponent` for sending audio and video via WebRTC from a Phoenix app to a browser (browser subscribes).\n\nIt will render a single HTMLVideoElement.\n\nOnce rendered, your `Phoenix.LiveView` will receive `t:init_msg/0` and can start\nsending RTP packets to the browser using `ExWebRTC.PeerConnection.send_rtp/4`, where\nthere first argument is a pid received in `t:init_msg/0`. For example:\n\n```elixir\nExWebRTC.PeerConnection.send_rtp(init_msg[:pc], init_msg[:audio_track_id], audio_packet)\nExWebRTC.PeerConnection.send_rtp(init_msg[:pc], init_msg[:video_track_id], video_packet)\n```\n\nSubscriber always negotiates a single audio and video track.","ref":"LiveExWebRTC.Subscriber.html"},{"type":"module","title":"Assigns - LiveExWebRTC.Subscriber","doc":"* `ice_servers` - a list of `t:ExWebRTC.PeerConnection.Configuration.ice_server/0`,\n* `ice_ip_filter` - `t:ExICE.ICEAgent.ip_filter/0`,\n* `ice_port_range` - `t:Enumerable.t(non_neg_integer())/1`,\n* `audio_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `video_codecs` - a list of `t:ExWebRTC.RTPCodecParameters.t/0`,\n* `gen_server_name` - `t:GenServer.name/0`\n* `class` - list of CSS/Tailwind classes that will be applied to the HTMLVideoPlayer. Defaults to \"\".","ref":"LiveExWebRTC.Subscriber.html#module-assigns"},{"type":"module","title":"JavaScript Hook - LiveExWebRTC.Subscriber","doc":"Subscriber live component requires JavaScript hook to be registered under `Subscriber` name.\nThe hook can be created using `createSubscriberHook` function.\nFor example:\n\n```javascript\nimport { createSubscriberHook } from \"live_ex_webrtc\";\nlet Hooks = {};\nconst iceServers = [{ urls: \"stun:stun.l.google.com:19302\" }];\nHooks.Subscriber = createSubscriberHook(iceServers);\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  // ...\n  hooks: Hooks\n});\n```","ref":"LiveExWebRTC.Subscriber.html#module-javascript-hook"},{"type":"module","title":"Examples - LiveExWebRTC.Subscriber","doc":"```elixir\n<.live_component\n  module={LiveExWebRTC.Subscriber}\n  id=\"subscriber\"\n  ice_servers={[%{urls: \"stun:stun.l.google.com:19302\"}]}\n/>\n```","ref":"LiveExWebRTC.Subscriber.html#module-examples"},{"type":"type","title":"LiveExWebRTC.Subscriber.init_msg/0","doc":"Message sent to the `Phoenix.LiveView` after component's initialization.\n\n* `pc` - `ExWebRTC.PeerConnection`'s pid spawned by this live component.\nIt can be used to send RTP packets to the browser using `ExWebRTC.PeerConnection.send_rtp/4`.\n* `audio_track_id` - id of audio track\n* `video_track_id` - id of video track","ref":"LiveExWebRTC.Subscriber.html#t:init_msg/0"},{"type":"extras","title":"LiveExWebRTC","doc":"# LiveExWebRTC\n\n[![Hex.pm](https://img.shields.io/hexpm/v/live_ex_webrtc.svg)](https://hex.pm/packages/live_ex_webrtc)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/live_ex_webrtc)\n\nPhoenix Live Components for Elixir WebRTC.","ref":"readme.html"},{"type":"extras","title":"Installation - LiveExWebRTC","doc":"In your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_ex_webrtc, \"~> 0.2.0\"}\n  ]\nend\n```\n\nIn your `tailwind.config.js`\n\n```js\nmodule.exports = {\n  content: [\n    \"../deps/live_ex_webrtc/**/*.*ex\" // ADD THIS LINE\n  ]\n}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - LiveExWebRTC","doc":"`LiveExWebRTC` comes with two `Phoenix.LiveComponent`s:\n* `LiveExWebRTC.Publisher` - sends audio and video via WebRTC from a web browser to a Phoenix app (browser publishes)\n* `LiveExWebRTC.Subscriber` - sends audio and video via WebRTC from a Phoenix app to a web browser (browser subscribes)\n\nSee module docs for more.","ref":"readme.html#usage"},{"type":"extras","title":"Local development - LiveExWebRTC","doc":"For local development:\n* include `live_ex_webrtc` in your `mix.exs` via `path` \n* modify `NODE_PATH` env variable in your esbuild configuration, which is located in `config.exs` - this will allow for importing javascript hooks from `live_ex_webrtc`.\n\n  For example:\n\n  ```elixir\n  config :esbuild,\n    # ...\n    default: [\n      # ...\n      env: %{\n        \"NODE_PATH\" => \"#{Path.expand(\"../deps\", __DIR__)}:/path/to/parent/dir/of/live_ex_webrtc\"\n      }\n    ]\n  ```\n\n* modify `content` in `tailwind.config.js` - this will compile tailwind classes used in live components.\n  \n  For example:\n\n  ```js\n  module.exports = {\n    content: [\n      // ...\n      \"../deps/**/*.ex\"\n    ]\n  }\n  ```\n\n> ##","ref":"readme.html#local-development"},{"type":"extras","title":"Important {: .info} - LiveExWebRTC","doc":"> Separate paths with `:` on MacOS/Linux and with `;` on Windows.\n\n> ##","ref":"readme.html#important-info"},{"type":"extras","title":"Important {: .info} - LiveExWebRTC","doc":"> Specify path to live_ex_webrtc's parent directory.","ref":"readme.html#important-info"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}